package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.TSosSolve;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TFallSolve;
import com.ruoyi.system.service.ITFallSolveService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 跌倒告警Controller
 * 
 * @author zhengjie
 * @date 2023-09-09
 */
@RestController
@RequestMapping("/system/fallsolve")
public class TFallSolveController extends BaseController
{
    @Autowired
    private ITFallSolveService tFallSolveService;

    /**
     * 查询跌倒告警列表
     */
    @PreAuthorize("@ss.hasPermi('system:fallsolve:list')")
    @GetMapping("/list")
    public TableDataInfo list(TFallSolve tFallSolve)
    {
        startPage();
        List<TFallSolve> list = tFallSolveService.selectTFallSolveList(tFallSolve);
        for (TFallSolve salve : list){
            if (StringUtils.isNull(salve.getSolve_status())){
                salve.setSolve_status(0);
            }
            salve.setAlarmMsg("跌倒告警求助：" + salve.getName() + "于" + DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,salve.getCreatetime()) + "发起跌倒告警求助");
        }
        return getDataTable(list);
    }

    /**
     * 导出跌倒告警列表
     */
    @PreAuthorize("@ss.hasPermi('system:fallsolve:export')")
    @Log(title = "跌倒告警", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TFallSolve tFallSolve)
    {
        List<TFallSolve> list = tFallSolveService.selectTFallSolveList(tFallSolve);
        ExcelUtil<TFallSolve> util = new ExcelUtil<TFallSolve>(TFallSolve.class);
        util.exportExcel(response, list, "跌倒告警数据");
    }

    /**
     * 获取跌倒告警详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:fallsolve:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(tFallSolveService.selectTFallSolveById(id));
    }

    /**
     * 新增跌倒告警
     */
    @PreAuthorize("@ss.hasPermi('system:fallsolve:add')")
    @Log(title = "跌倒告警", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TFallSolve tFallSolve)
    {
        return toAjax(tFallSolveService.insertTFallSolve(tFallSolve));
    }

    /**
     * 修改跌倒告警
     */
    @PreAuthorize("@ss.hasPermi('system:fallsolve:edit')")
    @Log(title = "跌倒告警", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TFallSolve tFallSolve)
    {
        return toAjax(tFallSolveService.updateTFallSolve(tFallSolve));
    }

    /**
     * 删除跌倒告警
     */
    @PreAuthorize("@ss.hasPermi('system:fallsolve:remove')")
    @Log(title = "跌倒告警", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(tFallSolveService.deleteTFallSolveByIds(ids));
    }
}
